#
# spec file for package perl-PDL
#
# Copyright (c) 2014 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           perl-PDL
%define cpan_name PDL
Version:        2.4.11
Release:        1.53
Summary:        PDL - perlDL module extension for perl
License:        BSD-3-Clause and (GPL-1.0+ or Artistic-1.0)
Group:          Development/Libraries/Perl
Url:            http://cpan.org/modules/by-module/PDL/
Source:         http://www.cpan.org/authors/id/C/CH/CHM/%{cpan_name}-%{version}.tar.gz
Patch0:         PDL-2.4.7.diff
Patch1:         PDL-2.4.7-return.diff
Patch2:         PDL-2.4.7-pdldoc.db.diff
Patch3:         PDL-2.4.7-makefile.diff
Patch4:         PDL-2.4.7-qsortvec.diff
Patch5:         PDL-2.4.7-ppdef.diff
Patch6:         PDL-2.4.7-strncat.diff
Patch7:         PDL-2.4.11-implicit.diff
Patch8:         PDL-2.4.11-hashcmp.diff
BuildRequires:  f2c
BuildRequires:  fftw3-devel
BuildRequires:  freeglut-devel
BuildRequires:  gcc-fortran
BuildRequires:  gsl-devel
BuildRequires:  ncurses-devel
BuildRequires:  perl
BuildRequires:  perl-Curses
BuildRequires:  perl-ExtUtils-F77
BuildRequires:  perl-Inline
BuildRequires:  perl-macros
BuildRequires:  xorg-x11
BuildRequires:  xorg-x11-Xvfb
Provides:       PDL
Provides:       perl_pdl
Obsoletes:      perl_pdl
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
The perlDL project aims to turn perl into an efficient numerical
language for scientific computing. The PDL module gives standard perl
the ability to compactly store and speedily manipulate the large
N-dimensional data sets.

%prep
%setup -n PDL-%{version} -q
%patch0
%patch1
%patch2
%patch3
%patch4
%patch5
%patch6
%patch7
%patch8

%build
perl Makefile.PL
make -j1 CCCDLFLAGS="-fPIC -fno-aggressive-loop-optimizations -DPERL_REENTR_API=1" #to make the tests of srand pass

%check
Xvfb :95 &
trap "kill $! || true" EXIT
sleep 5
# the following tests are disabled for the reason specified
mv t/flexraw.t t/flexraw.tt # gfortran format not compatible to g77
%ifarch sparc s390x s390 x86_64
  mv t/slatec.t t/slatec.tt     # a bug somewhere in chid() function
%endif
mv t/opengl.t t/opengl.tt # does not work with Xvfb server
mv t/xvals.t t/xvals.tt #mysterioously fails, see upstream #1744014
DISPLAY=:95 make test

%install
make DESTDIR=%{buildroot} install_vendor
mv %{buildroot}%{_prefix}/lib/perl5/%{perl_version} %{buildroot}%{_prefix}/lib/perl5/%{perl_version}.tmp
cp -R /usr/lib/perl5/%{perl_version} %{buildroot}%{_prefix}/lib/perl5
perl -I blib/lib -I blib/arch Doc/scantree.pl %{buildroot}%{perl_vendorarch}
rm -rf %{buildroot}%{_prefix}/lib/perl5/%{perl_version}
mv %{buildroot}%{_prefix}/lib/perl5/%{perl_version}.tmp %{buildroot}%{_prefix}/lib/perl5/%{perl_version}
%perl_process_packlist
for i in `find %{buildroot}/%{perl_vendorarch}/PDL/HtmlDocs/PDL/ -type f`; do
	sed s:%{buildroot}::g < $i > $i.tmp
	mv $i.tmp $i
done
rm -rf %{buildroot}%{_localstatedir}/adm/perl-modules/perl-PDL

%clean
rm -rf %{buildroot}

%files
%defattr(-,root,root)
%doc Known_problems TODO README COPYING DEVELOPMENT Changes Release_Notes BUGS DEPENDENCIES MANIFEST Example
%doc %{_mandir}/man?/*
%{perl_vendorarch}/auto/PDL
%{perl_vendorarch}/PDL
%{perl_vendorarch}/Inline
%{perl_vendorarch}/PDL.pm
%{_bindir}/*

%changelog
* Tue Jul 16 2013 mls@suse.de
- use -fno-aggressive-loop-optimizations instead of -fno-tree-ch
* Mon Jul 15 2013 mls@suse.de
- added patch: PDL-2.4.11-hashcmp.diff
  fix testcase so that it can cope with hash randomization
- compile with -fno-tree-ch to work around a gcc 4.8.1 compiler bug
* Mon Jun 11 2012 mls@suse.de
- update to 2.4.11 to make it work with perl-5.16.0
  * a new implementation mapflex and mapfraw routines provides
  memory-mapped IO for all platforms including win32 systems.
  * the new memory mapped IO support is implemented using
  File::Map so version 0.47 has been added as a required
  dependency to force automated testing so an automated build
  will need this dependency installed.
  * various cleanup to existing code to fix warnings generated
  by perl versions 5.15.x and higher.
* Wed Dec 14 2011 coolo@suse.com
- fix license to be in spdx.org format
* Fri Nov 18 2011 coolo@suse.com
- use original tar.gz
* Wed Apr 13 2011 vcizek@novell.com
- corrected license to BSD and (GPL+ or Artistic)
* Wed Apr 13 2011 vcizek@novell.com
- update to 2.4.9
  General Notes:
  * Fixes a couple of surprise bugs that were discovered
    immediately with the PDL-2.4.8 release.
  Highlights:
  * Fix sf.net bug #3267408 "t/slice.t crashes in tests 68-70 for BSD"
  * Fix sf.net bug #3190227 "PDL build fails with parallel GNU make -j3 -j3"
  * Fixed various tempfile name generation problems by switching
    to File::Temp instead of hand rolled solutions.
    This is the recommended approach going forward.
  * Force Convert::UU usage for BSD to work around a t/dumper.t
    failure on MirBSD.
* Fri Apr  1 2011 vcizek@novell.com
- update to 2.4.8
  - many bugs fixed
  New Features or Functionality:
  * New PDL::Constants module providing PI and E (so far)
  * Inplace support added for PDL::Complex operations
  * pdldoc and the pdl2/perldl help commands now print all
    matches by default when multiple matches are found.
  * readflex/writeflex/mapflex now support reading and writing
    piddles with bad values in them. This was sf.net feature
    request #3028127, "add badvalue support to FlexRaw".
  * writeflex now supports automatically calling the
    writeflexhdr() routine if you have set the variable
    $PDL::FlexRaw::writeflexhdr to a true value and are
    writing to a file given by filename as argument.
  * Updated the error handling for GSL::INTERP to match other
    GSL module usages.
  * Applied sf.net patch #3209075 IO::HDF square sds
  * New binary blob support in PDL::IO::GD::OO
* Sun Jan 23 2011 coolo@novell.com
- fix build on 11.4 and ran spec-cleaner
* Mon Nov 29 2010 coolo@novell.com
- remove /var/adm/perl-modules
* Fri Aug 20 2010 anicka@suse.cz
- update to 2.4.7
  * New 2-D image display routine: imag2d()
  * pdl() constructor, a.k.a. PDL->new(), now
  takes string arguments with either MATLAB type
  concatenation syntax or PDL print output (for
  easier cut-and-paste from PDL shell sessions).
  * Improved text and comma separated value file
  input via rcols(): faster and more flexible.
  * A new PDL shell based on Devel::REPL (i.e.,
  Moose technology).  The new shell supports
  more perl syntax (lexical variables and
  packages), is more extensible (via a system
  of plugins), and supports many forms of file
  and variable completion.
  Install Devel::REPL and give it a try!
  User feedback welcome.
  * More portability (builds on more platforms
  with more features than ever).
  * Many bugs fixed...
* Tue Apr 20 2010 davejplater@gmail.com
- Changed build dependency from fftw to fftw3
* Tue Apr  6 2010 coolo@novell.com
- disable parallel build to avoid random failures we saw
* Fri Feb 26 2010 anicka@suse.cz
- update to 2.4.6
  * bugfixes, test fixes
* Sun Jan 10 2010 jengelh@medozas.de
- enable parallel build
* Sun Nov 29 2009 crrodriguez@opensuse.org
- fix build
* Fri May 22 2009 anicka@suse.cz
- add the strncat patch
* Tue May 19 2009 anicka@suse.cz
- call strncat correctly
* Fri Feb 27 2009 anicka@suse.cz
- update to 2.4.4
  * bugfixes
* Mon Mar  3 2008 anicka@suse.cz
- workaround problem with incompatible random generators
- disable xvals.t (upstream bugzilla #1744014)
- fix undefined operation in pp_def
* Fri Mar 30 2007 aj@suse.de
- Cleanup buildrequires.
* Thu Feb 15 2007 anicka@suse.cz
- fix build (call Doc/scantree.pl with right path in %%install)
* Wed Dec 13 2006 anicka@suse.cz
- fix invalid operation in IIS.xs
* Wed Sep 13 2006 anicka@suse.cz
- update to 2.4.3
  * Modified gsl_interp.pd and gsl_random.pd to pass pointers
  as IVs
  (removed our patches fixing the same problem)
  * bugfixes, documentation added
  * Modified PDL::GSL::INTEG to enable the calculation
  of nested integrals
* Fri Aug 18 2006 anosek@suse.cz
- disable opengl test, does not work with Xvfb server
* Mon Mar 27 2006 mls@suse.de
- fix qsortvec for platforms with unsigned char
* Tue Jan 31 2006 mls@suse.de
- workaround makefile problem with perl-5.8.8
- disable flexraw test, does not work with gfortran
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon Aug  1 2005 mjancar@suse.cz
- update to 2.4.2
- fix implicit prototypes
* Mon Feb 14 2005 schwab@suse.de
- Fix invalid casts.
* Mon Feb 14 2005 schwab@suse.de
- Fix missing declarations.
* Wed May 12 2004 mjancar@suse.cz
- genereate documentation database (#38504)
* Tue Apr 27 2004 mjancar@suse.cz
- mark void functions as such
- disable tests that fail on certain architectures
* Sat Apr 24 2004 sndirsch@suse.de
- use xorg-x11 packages
* Thu Apr  1 2004 mls@suse.de
- ppc64 also has 64bit
* Wed Mar 31 2004 mls@suse.de
- fix gsl interp on 64bit platforms
* Wed Mar 31 2004 mls@suse.de
- fix range operator for 64bit platforms
* Tue Mar  2 2004 mjancar@suse.cz
- update to 2.4.1
* Sun Feb 22 2004 ro@suse.de
- added libusb and resmgr to neededforbuild
* Sat Jan 10 2004 adrian@suse.de
- add %%defattr
* Mon Jul 21 2003 mjancar@suse.cz
- adapt to perl-5.8.1
- use %%perl_process_packlist
* Thu Jun 26 2003 ro@suse.de
- remove traces of buildroot in documentation
  (fix basedir for find command)
* Tue May 20 2003 mjancar@suse.cz
- remove unpackaged files
* Mon Mar 31 2003 ro@suse.de
- use mesa-devel-packages in neededforbuild
* Thu Dec  5 2002 prehak@suse.cz
- updated to version 2.3.4
- added freetype2 to neededforbuild
- disabled slatec.t for sparc
* Mon Nov 11 2002 ro@suse.de
- updated neededforbuild after xf86-rename
* Thu Oct 17 2002 prehak@suse.cz
- fixed for lib64 archs
- disabled some tests for axp
* Sat Oct 12 2002 prehak@suse.cz
- used Xvfb to enable and pass t/opengl.t test
* Wed Sep 18 2002 prehak@suse.cz
- fixed callext.t test
- rejected some specified tests, but enabled make test
* Mon Jul 29 2002 mls@suse.de
- Fixed neededforbuild for perl-5.8.0
* Mon Jul 22 2002 prehak@suse.cz
- update to version 2.3.3
- added Example directory and more to documentation
* Fri May 24 2002 ro@suse.de
- use -fPIC when building shared object
* Sun Feb  3 2002 schwab@suse.de
- Add mesa, mesaglu and mesasoft to neededforbuild.
- Fix race when polishing .packlist.
- Fix for 64bit platforms.
* Wed Jan 16 2002 rvasice@suse.cz
- update to version 2.3.2
- spec file cleanup
* Tue Jun 26 2001 ro@suse.de
- update to 2.2.1  ( to make it build )
* Wed May  9 2001 mfabian@suse.de
- bzip2 sources
* Tue Nov 14 2000 pblaha@suse.cz
- rename to perl-PDL
* Wed Aug 23 2000 bubnikv@suse.cz
- updated to 2.1.1
* Fri May 26 2000 bubnikv@suse.cz
- sorted
* Fri Mar 31 2000 bubnikv@suse.cz
- new version (2.004)
- added buildroot
* Thu Jan 20 2000 ro@suse.de
- use macro for mandir
* Tue Oct 19 1999 fehr@suse.de
- changed to new version 2.002
* Mon Sep 13 1999 bs@suse.de
- ran old prepare_spec on spec file to switch to new prepare_spec.
* Fri Apr 30 1999 ro@suse.de
- fixed to build on alpha
* Wed Apr 14 1999 fehr@suse.de
- add version 2.0 of package to SuSE distribution
